@@ -183,6 +183,7 @@ class class4gl_input(object):
         theta      = 288.   ,  # initial mixed-layer potential temperature [K]
         dtheta     = 1.     ,  # initial temperature jump at h [K]
         gammatheta = 0.006  ,  # free atmosphere potential temperature lapse rate [K m-1]
+        gammatheta_lower_limit = 0.002,
         advtheta   = 0.     ,  # advection of heat [K s-1]
         beta       = 0.2    ,  # entrainment ratio for virtual heat [-]
         wtheta     = 0.1    ,  # surface kinematic heat flux [K m s-1]
@@ -553,7 +554,7 @@ class class4gl_input(object):
         string =  '\n'.join(string)
         
         columns = [ 'PRES', 'HGHT', 'TEMP', 'DWPT', 'RELH', 'MIXR', 'DRCT','SKNT' , 'THTA','THTE', 'THTV']             
-        air_balloon = pd.read_fwf(io.StringIO(str(string)),widths=[7]*11,names=columns,skiprows=5,dtype=np.float,skipfooter=0)#.iloc[5:-1]
+        air_balloon_in = pd.read_fwf(io.StringIO(str(string)),widths=[7]*11,names=columns,skiprows=5,dtype=np.float,skipfooter=0)#.iloc[5:-1]
         #ONE_COLUMN = pd.read_table(io.StringIO(str(string)),sep=r"\s*",skiprows=[0,1,3,4])
         
         #string =  soup.pre.next_sibling.next_sibling
@@ -562,7 +563,7 @@ class class4gl_input(object):
         
         # this crazy long line just loads the sounding parameter table into parameters object (using amongst others the pandas internal engine to detect the right value types (int, float, np.Datetime64 etc.)).
         dpars = {**dpars,
-                **pd.read_fwf(io.StringIO(str(string)),widths=[43,1,20],names=['descr','dummy','value']).iloc[1:-1].drop("dummy",1).set_index("descr").T.convert_objects(convert_numeric=True).iloc[0].to_dict()
+                **pd.read_fwf(io.StringIO(str(string)),widths=[43,1,20],names=['descr','dummy','value']).iloc[1:-1].drop("dummy",1).set_index("descr").T.apply(pd.to_numeric,errors='ignore').iloc[0].to_dict()
                }
         
         # we get weird output when it's a numpy Timestamp, so we convert it to
@@ -572,17 +573,18 @@ class class4gl_input(object):
         dpars['STNID'] = dpars['Station number']
 
         # altitude above ground level
-        air_balloon['z'] = air_balloon.HGHT -dpars['Station elevation']
+        air_balloon = pd.DataFrame()
+        air_balloon['z'] = air_balloon_in.HGHT -dpars['Station elevation']
         # absolute humidity in g/kg
-        air_balloon['q']= (air_balloon.MIXR/1000.) \
+        air_balloon['q']= (air_balloon_in.MIXR/1000.) \
                               / \
-                             (air_balloon.MIXR/1000.+1.)
+                             (air_balloon_in.MIXR/1000.+1.)
         # convert wind speed from knots to m/s
-        air_balloon['WSPD'] = 0.51444 * air_balloon.SKNT
-        angle_x = (90.-air_balloon.DRCT)/180.*np.pi # assuming that wind in direction of the south is 0 degrees.
+        air_balloon['V'] = 0.51444 * air_balloon_in.SKNT
+        angle_x = (90.-air_balloon_in.DRCT)/180.*np.pi # assuming that wind in direction of the south is 0 degrees.
         
-        air_balloon['u'] = air_balloon.WSPD * np.sin(angle_x)
-        air_balloon['v'] = air_balloon.WSPD * np.cos(angle_x)
+        air_balloon['u'] = air_balloon.V * np.sin(angle_x)
+        air_balloon['v'] = air_balloon.V * np.cos(angle_x)
 
         
 
@@ -591,27 +593,43 @@ class class4gl_input(object):
         Rv         = 461.5                 # gas constant for moist air [J kg-1 K-1]
 
         air_balloon['R'] = (Rd*(1.-air_balloon.q) + Rv*air_balloon.q)
-        air_balloon['p'] = air_balloon.PRES*100.
+        air_balloon['p'] = air_balloon_in.PRES*100.
 
+        air_balloon['t'] = air_balloon_in['TEMP']+273.15
 
         # Therefore, determine the sounding that are valid for 'any' column 
         is_valid = ~np.isnan(air_balloon).any(axis=1) & (air_balloon.z >= 0)
         #is_valid = (air_balloon.z >= 0)
         # # this is an alternative pipe/numpy method
         # (~np.isnan(air_balloon).any(axis=1) & (air_balloon.z >= 0)).pipe(np.where)[0]
-        valid_indices = air_balloon.index[is_valid].values
+        valid_indices = air_balloon.index[is_valid]
+        air_balloon = air_balloon[is_valid].reset_index()
         #print(valid_indices)
 
-        dpars['Ps'] = air_balloon.p.iloc[valid_indices[0]]
 
-        air_balloon['t'] = air_balloon['TEMP']+273.15
-        air_balloon['theta'] = (air_balloon.t) * \
-                   (dpars['Ps']/(air_balloon.PRES*100.))**(air_balloon['R']/cp)
-        air_balloon['thetav']   = air_balloon['theta']*(1. + 0.61 * air_balloon['q'])
+        if len(air_balloon) > 2:
+
+            dpars['Ps'] = air_balloon.p.values[0]
+            air_balloon['theta'] = (air_balloon.t) * \
+                       (dpars['Ps']/(air_balloon.p))**(air_balloon['R']/cp)
+            air_balloon['thetav']   = air_balloon['theta']*(1. + 0.61 * air_balloon['q'])
+
+            # t_cut_off = 1.5
+            # i = 1
+            # if t_cut_off is not None:
+            #     
+            #     while ((i < len(air_balloon)) and \
+            #           ((air_balloon.thetav[0] - air_balloon.thetav[i] ) > t_cut_off)):
+            #         #diff = (air_balloon.theta.iloc[valid_indices[i]] -air_balloon.theta.iloc[valid_indices[i+1]])- 0.5
+            #         air_balloon.thetav[0:i] = \
+            #                 air_balloon.thetav[i] + t_cut_off
+            #         
+            #         i +=1
+
+
 
-        if len(valid_indices) > 0:
             #calculated mixed-layer height considering the critical Richardson number of the virtual temperature profile
-            dpars['h'],dpars['h_u'],dpars['h_l'] = blh(air_balloon.z,air_balloon.thetav,air_balloon.WSPD)
+            dpars['h'],dpars['h_u'],dpars['h_l'] = blh(air_balloon.z,air_balloon.thetav,air_balloon.V)
             
             dpars['h_b'] = np.max((dpars['h'],10.))
             dpars['h_u'] = np.max((dpars['h_u'],10.)) #upper limit of mixed layer height
@@ -626,28 +644,22 @@ class class4gl_input(object):
             dpars['h_l'] =np.nan
             dpars['h_e'] =np.nan
             dpars['h'] =np.nan
-
-
-        if np.isnan(dpars['h']):
             dpars['Ps'] = np.nan
+            air_balloon['t'] = np.nan
+            air_balloon['theta'] = np.nan
+            air_balloon['thetav'] = np.nan
 
         if ~np.isnan(dpars['h']):
             # determine mixed-layer properties (moisture, potential temperature...) from profile
             
             # ... and those of the mixed layer
-            is_valid_below_h = is_valid & (air_balloon.z < dpars['h'])
+            is_valid_below_h = (air_balloon.z < dpars['h'])
             valid_indices_below_h =  air_balloon.index[is_valid_below_h].values
-            if len(valid_indices) > 1:
-                if len(valid_indices_below_h) >= 3.:
-                    ml_mean = air_balloon[is_valid_below_h].mean()
-                else:
-                    ml_mean = air_balloon.iloc[valid_indices[0]:valid_indices[1]].mean()
-            elif len(valid_indices) == 1:
-                ml_mean = (air_balloon.iloc[0:1]).mean()
+            if len(valid_indices_below_h) >= 2.:
+                ml_mean = air_balloon[is_valid_below_h].mean()
             else:
-                temp =  pd.DataFrame(air_balloon)
-                temp.iloc[0] = np.nan
-                ml_mean = temp
+                ml_mean = air_balloon.iloc[0:1].mean()
+                    
                        
             dpars['theta']= ml_mean.theta
             dpars['q']    = ml_mean.q
@@ -668,9 +680,9 @@ class class4gl_input(object):
         #calculate mixed-layer jump ( this should be larger than 0.1)
         
         air_ap_head['z'] = pd.Series(np.array([2.,dpars['h'],dpars['h']]))
-        air_ap_head['HGHT'] = air_ap_head['z'] \
-                                + \
-                                np.round(dpars[ 'Station elevation'],1)
+        # air_ap_head['HGHT'] = air_ap_head['z'] \
+        #                         + \
+        #                         np.round(dpars[ 'Station elevation'],1)
         
         # make a row object for defining the jump
         jump = air_ap_head.iloc[0] * np.nan
@@ -705,7 +717,7 @@ class class4gl_input(object):
         
                air_ap_head[column][2] += jump[column]
         
-        air_ap_head.WSPD = np.sqrt(air_ap_head.u**2 +air_ap_head.v**2)
+        air_ap_head.V = np.sqrt(air_ap_head.u**2 +air_ap_head.v**2)
 
 
 
@@ -827,9 +839,7 @@ class class4gl_input(object):
 
         # we round the columns to a specified decimal, so that we get a clean
         # output format for yaml
-        decimals = {'p':0,'HGHT':1,'t':2,'DWPT':2,'RELH':2,'MIXR':2,\
-                   'DRCT':2 ,'SKNT':2,   'theta':4,   'THTE':2,  'THTV':2,\
-                   'z':2, 'q':5, 'WSPD':2, 'u':4,       'v':4}
+        decimals = {'p':0, 't':2, 'theta':4, 'z':2, 'q':5, 'V':2, 'u':4, 'v':4}
 # 
         for column,decimal in decimals.items():
             air_balloon[column] = air_balloon[column].round(decimal)
@@ -1067,9 +1077,9 @@ class class4gl_input(object):
                         if globaldata.datasets[key].page.variables['lon'].values[ilonmin] > globaldata.datasets[key].page.variables['lon'].values[ilon]:
                             ilonmin = ilon        
                         
-                        # for the koeppen climate classification we just take nearest
+                        # for the koeppen climate classification and midsummermonth, we just take nearest
                         print(key)
-                        if key == 'KGC':
+                        if key in ['KGC','midsummermonth','AI']:
                             ilatrange = range(ilat,ilat+1)
                             ilonrange = range(ilon,ilon+1)
                         else:
@@ -1088,7 +1098,8 @@ class class4gl_input(object):
                             
                             idatetime = np.where((DIST) == np.min(DIST))[0][0]
                             #print('idatetime',idatetime,globaldata.datasets[key].variables['time'].values[idatetime],classdatetime)
-                            if key not in ['Tsoil','T2']:
+
+                            if key not in ['Tsoil','T2','blptb_daymax','t2m_daymax','t2m','blpt','blpt_afternoon','blh','t2m_afternoon','blh_afternoon','blq','blq_afternoon','blptb','blptb_afternoon','blptw','blptw_afternoon','HI','HI_afternoon','rh100','rh100_afternoon']:
                                 if ((globaldata.datasets[key].page.variables['time'].values[idatetime] < classdatetime) ):
                                     idatetime += 1
                             
@@ -1107,9 +1118,9 @@ class class4gl_input(object):
                                 idatetime = idatetime - 1
                                 idatetimeend = idatetimeend - 1
 
-                            # in case of soil temperature, we take the exact
+                            # in case of soil temperature or maximum daytime temperature, we take the exact
                             # timing (which is the morning)
-                            if key in ['Tsoil','T2']:
+                            if key in ['Tsoil','T2','t2m_daymax','t2m','blpt','blpt_afternoon','blh','t2m_afternoon','blh_afternoon','blq','blq_afternoon','blptb','blptb_afternoon','blptw','blptw_afternoon','HI','HI_afternoon','rh100','rh100_afternoon']:
                                 idatetimeend = idatetime
                             
                             idts = range(idatetime,idatetimeend+1)
@@ -1458,13 +1469,6 @@ class class4gl_input(object):
         # and now we can get the surface values
         #class_settings = class4gl_input()
         #class_settings.set_air_input(input_atm)
-        
-        # we only allow non-polar stations
-        if not (self.pars.lat <= 60.):
-            source_globaldata_ok = False
-            self.logger.warning('cveg  is invalid: ('+str(self.pars.cveg)+')')
-        
-        # check lat and lon
         if (pd.isnull(self.pars.lat)) or (pd.isnull(self.pars.lon)):
             source_globaldata_ok = False
             self.logger.warning('lat  is invalid: ('+str(self.pars.lat)+')')
@@ -1585,7 +1589,6 @@ class class4gl_input(object):
             mlvalues['v']  = np.nan
             
 
-        self.update(source='fit_from_'+source,pars=mlvalues)
 
 
         # First 3 data points of the mixed-layer fit. We create a empty head
@@ -1633,10 +1636,11 @@ class class4gl_input(object):
                   jump.theta = np.max((0.1,jump.theta))
         
                air_ap_head[column][2] += jump[column]
+               mlvalues['d'+column] = jump[column]
         
-        air_ap_head.WSPD = np.sqrt(air_ap_head.u**2 +air_ap_head.v**2)
-
+        self.update(source='fit_from_'+source,pars=mlvalues)
 
+        air_ap_head.V = np.sqrt(air_ap_head.u**2 +air_ap_head.v**2)
 
         # make theta increase strong enough to avoid numerical
         # instability
@@ -1968,22 +1972,27 @@ class class4gl(model):
 
         dictout = {}
         dictoutlast = {}
-        if timeseries_only == None:
-            outvars = self.__dict__['out'].__dict__.keys()
+        if not 'out' in self.__dict__.keys():
+            print('Warning: no timeseries section found in output.')
         else:
-            outvars = timeseries_only
-        for key in outvars:
-            dictout[key] = self.__dict__['out'].__dict__[key]
-            dictoutlast[key] = dictout[key][-1]
+            outvars = []
+            if timeseries_only == None:
+                    outvars = self.__dict__['out'].__dict__.keys()
+            else:
+                outvars = timeseries_only
 
-            if type(dictoutlast[key]).__module__ == 'numpy':
-                dictoutlast[key] = dictoutlast[key].item() 
-            # convert numpy types to native python data types. This
-            # provides cleaner data IO with yaml:
-            if type(dictout[key]).__module__ == 'numpy':
-                dictout[key] = [ a.item() for a in \
-                                 self.__dict__['out'].__dict__[key]]
-            #dictout[key] = list(dictout[key] )
+            for key in outvars:
+                dictout[key] = self.__dict__['out'].__dict__[key]
+                dictoutlast[key] = dictout[key][-1]
+
+                if type(dictoutlast[key]).__module__ == 'numpy':
+                    dictoutlast[key] = dictoutlast[key].item() 
+                # convert numpy types to native python data types. This
+                # provides cleaner data IO with yaml:
+                if type(dictout[key]).__module__ == 'numpy':
+                    dictout[key] = [ a.item() for a in \
+                                     self.__dict__['out'].__dict__[key]]
+                #dictout[key] = list(dictout[key] )
 
         yaml.dump({'pars' : {**dictoutlast,**dictpars}},file)
 
