@@ -124,8 +124,6 @@ for key in args.experiments.strip(' ').split(' '):
 
 sns.reset_orig()
 
-
-
 lookup_symbols= {
  'A':'equatorial',
  'B':'arid',
@@ -248,6 +246,9 @@ for ikoeppen,koeppen in koeppenlookuptable.iterrows():
 koeppenlookuptable = koeppenlookuptable.sort_values('amount',ascending=False)
 include_koeppen = list(koeppenlookuptable.KGCID)
 
+for ikey,key in enumerate(args.experiments.strip(' ').split(' ')[:2]):
+    c4gldata[key].frames['stats']['records_all_stations_ini']['KGCname'] =  \
+        c4gldata[key].frames['stats']['records_all_stations_ini']['KGC'].map(koeppenlookuptable['KGCID'])
 
 if args.make_figures:
     fig = plt.figure(figsize=(11,8.0))   #width,height
@@ -305,16 +306,17 @@ if args.make_figures:
         #dia.ax.plot(x99,y99,color='k')
         i += 1
     
+
     i = 1
     for varkey in ['h','theta','q']:                                                    
         #for ikey,key in enumerate(args.experiments.strip(' ').split(' ')):
-        for ikey,key in enumerate(args.experiments.strip(' ').split(' ')[:1]):
+        for ikey,key in enumerate(args.experiments.strip(' ').split(' ')[:2]):
             # cc = c4gldata[key].frames['stats']['records_all_stations_ini']['cc']
             # clearsky = (cc < 0.05)
-            # mod = c4gldata[key].frames['stats']['records_all_stations_mod_stats'].loc[clearsky]['d'+varkey+'dt']
-            # obs = c4gldata[key].frames['stats']['records_all_stations_obs_afternoon_stats'].loc[clearsky]['d'+varkey+'dt']
-            mod = c4gldata[key].frames['stats']['records_all_stations_mod_stats']['d'+varkey+'dt']
-            obs = c4gldata[key].frames['stats']['records_all_stations_obs_afternoon_stats']['d'+varkey+'dt']
+            # mod = c4gldata[key].frames['stats']['records_all_stations_end_mod_stats'].loc[clearsky]['d'+varkey+'dt']
+            # obs = c4gldata[key].frames['stats']['records_all_stations_obs_end_obs_stats'].loc[clearsky]['d'+varkey+'dt']
+            mod = c4gldata[key].frames['stats']['records_all_stations_end_mod_stats']['d'+varkey+'dt']
+            obs = c4gldata[key].frames['stats']['records_all_stations_end_obs_stats']['d'+varkey+'dt']
 
             print ('filtering classes that have sufficient samples: ', include_koeppen)
             filter_classes = (c4gldata[key].frames['stats']['records_all_stations_ini'].KGCname.isin(include_koeppen))
@@ -329,6 +331,7 @@ if args.make_figures:
             RMSE = rmse(obs,mod)                                               
             BIAS = np.mean(mod) - np.mean(obs)
             STD = mod.std()
+            markers=['o','^']
             
             # fit = np.polyfit(x,y,deg=1)
             # axes[varkey].plot(x, fit[0] * x + fit[1],\
@@ -342,23 +345,23 @@ if args.make_figures:
             # print(STD)
             # print(PR)
             dias[varkey].add_sample(STD/STD_OBS, PR,\
-                           marker='o',ls='', mfc='white',mec='black',
+                           marker=markers[ikey],ls='', mfc='white',mec='black',
                            zorder=-100,
-                           ms=3.5*np.sqrt(np.sum(np.array(koeppenlookuptable.amount.values,dtype=np.float)))/\
+                           ms=2.5*np.sqrt(np.sum(np.array(koeppenlookuptable.amount.values,dtype=np.float)))/\
                                 np.mean(np.sqrt(np.array(koeppenlookuptable.amount.values,dtype=np.float)))
                            # annotate=koeppen.KGCID, color=koeppen.textcolor,weight='bold',fontsize=5.,\
                            # bbox={'edgecolor':'black','boxstyle':'circle','fc':koeppen.color,'alpha':0.7}
                            )
             dias[varkey].add_sample(STD/STD_OBS, PR,\
-                           marker='o',ls='', mfc='none',mec='black',
+                           marker=markers[ikey],ls='', mfc='none',mec='black',
                            zorder=700,
-                           ms=3.5*np.sqrt(np.sum(np.array(koeppenlookuptable.amount.values,dtype=np.float)))/\
+                           ms=2.5*np.sqrt(np.sum(np.array(koeppenlookuptable.amount.values,dtype=np.float)))/\
                                 np.mean(np.sqrt(np.array(koeppenlookuptable.amount.values,dtype=np.float)))
                            # annotate=koeppen.KGCID, color=koeppen.textcolor,weight='bold',fontsize=5.,\
                            # bbox={'edgecolor':'black','boxstyle':'circle','fc':koeppen.color,'alpha':0.7}
                            )
             dias[varkey].add_sample(STD/STD_OBS, PR,\
-                           marker='o',ls='', mfc='none',mec='black',
+                           marker=markers[ikey],ls='', mfc='none',mec='black',
                            zorder=700,
                            ms=1.
                            # annotate=koeppen.KGCID, color=koeppen.textcolor,weight='bold',fontsize=5.,\
@@ -381,16 +384,16 @@ if args.make_figures:
     i = 1
     for varkey in ['h','theta','q']:                                                    
 
-        for ikey,key in enumerate(args.experiments.strip(' ').split(' ')[:1]):
+        for ikey,key in enumerate(args.experiments.strip(' ').split(' ')[:2]):
             icolor = 0
             for ikoeppen,koeppen in koeppenlookuptable.iterrows():
                 if koeppen.amount >= 200:
                     print(ikoeppen,':',koeppen)
                     kgc_select = (c4gldata[key].frames['stats']['records_all_stations_ini']['KGCname'] == koeppen['KGCID'])
-                    koeppen_mod = c4gldata[key].frames['stats']['records_all_stations_mod_stats']['d'+varkey+'dt'][kgc_select]
-                    koeppen_obs = c4gldata[key].frames['stats']['records_all_stations_obs_afternoon_stats']['d'+varkey+'dt'][kgc_select]
+                    koeppen_end_mod = c4gldata[key].frames['stats']['records_all_stations_end_mod_stats']['d'+varkey+'dt'][kgc_select]
+                    koeppen_obs = c4gldata[key].frames['stats']['records_all_stations_end_obs_stats']['d'+varkey+'dt'][kgc_select]
     
-                    #axes[varkey].scatter(koeppen_obs,koeppen_mod,marker=symbols[ikoeppen],color=colors[ikey])
+                    #axes[varkey].scatter(koeppen_obs,koeppen_end_mod,marker=symbols[ikoeppen],color=colors[ikey])
                              #  label=key+", "+\
                              #                    'R = '+str(round(PR[0],3))+', '+\
                              #                    'RMSE = '+str(round(RMSE,5))+', '+\
@@ -403,28 +406,28 @@ if args.make_figures:
                 # #                              'RMSE = '+str(round(RMSE,5))+', '+\
                 # #                              'BIAS = '+str(round(BIAS,5)),s=1.,color=colors[ikey])
                     
-                    dias[varkey].add_sample(koeppen_mod.std()/koeppen_obs.std(),
-                                   pearsonr(koeppen_mod,koeppen_obs)[0],
-                                   marker='o',linewidth=0.5,
+                    dias[varkey].add_sample(koeppen_end_mod.std()/koeppen_obs.std(),
+                                   pearsonr(koeppen_end_mod,koeppen_obs)[0],
+                                   marker=markers[ikey],linewidth=0.5,alpha=0.7,
                                             mfc=koeppen.color,mec='black',#koeppen.color,
                                             zorder=300+icolor,
-                                   ms=3.5*np.sqrt(koeppen.amount)/np.mean(np.sqrt(np.array(koeppenlookuptable.amount.values,dtype=np.float)))
-                                   # annotate=koeppen.KGCID, color=koeppen.textcolor,weight='bold',fontsize=5.,\
-                                   # bbox={'edgecolor':'black','boxstyle':'circle','fc':koeppen.color,'alpha':0.7}
-                                   )
-                    dias[varkey].add_sample(koeppen_mod.std()/koeppen_obs.std(),
-                                   pearsonr(koeppen_mod,koeppen_obs)[0],
-                                   marker='o',linewidth=0.5,
-                                            mfc=koeppen.color,mec='black',#koeppen.color,
-                                            zorder=301+icolor, ms=1
+                                   ms=2.5*np.sqrt(koeppen.amount)/np.mean(np.sqrt(np.array(koeppenlookuptable.amount.values,dtype=np.float)))
                                    # annotate=koeppen.KGCID, color=koeppen.textcolor,weight='bold',fontsize=5.,\
                                    # bbox={'edgecolor':'black','boxstyle':'circle','fc':koeppen.color,'alpha':0.7}
                                    )
+                    # dias[varkey].add_sample(koeppen_end_mod.std()/koeppen_obs.std(),
+                    #                pearsonr(koeppen_end_mod,koeppen_obs)[0],
+                    #                marker=markers[ikey],linewidth=0.5,
+                    #                         mfc=koeppen.color,mec='black',#koeppen.color,
+                    #                         zorder=301+icolor, ms=1
+                    #                # annotate=koeppen.KGCID, color=koeppen.textcolor,weight='bold',fontsize=5.,\
+                    #                # bbox={'edgecolor':'black','boxstyle':'circle','fc':koeppen.color,'alpha':0.7}
+                    #                )
 
 
-                    # dias[varkey].add_sample(koeppen_mod.std()/koeppen_obs.std(),
-                    #                pearsonr(koeppen_mod,koeppen_obs)[0],
-                    #                         marker='o',linewidth=0.5, mfc='none',mec=str(koeppen.color),
+                    # dias[varkey].add_sample(koeppen_end_mod.std()/koeppen_obs.std(),
+                    #                pearsonr(koeppen_end_mod,koeppen_obs)[0],
+                    #                         marker=markers[ikey],linewidth=0.5, mfc='none',mec=str(koeppen.color),
                     #                         zorder=600+icolor,
                     #                ms=10.*np.sqrt(koeppen.amount)/np.mean(np.sqrt(np.array(koeppenlookuptable.amount.values,dtype=np.float)))
                     #                # annotate=koeppen.KGCID, color=koeppen.textcolor,weight='bold',fontsize=5.,\
@@ -526,15 +529,16 @@ if args.make_figures:
         # cc = c4gldata[key].frames['stats']['records_all_stations_ini']['cc']
         # clearsky = (cc < 0.05)
     
-        # mod = c4gldata[key].frames['stats']['records_all_stations_mod_stats'].loc[clearsky]['d'+varkey+'dt']
-        # obs = c4gldata[key].frames['stats']['records_all_stations_obs_afternoon_stats'].loc[clearsky]['d'+varkey+'dt']
+        # mod = c4gldata[key].frames['stats']['records_all_stations_end_mod_stats'].loc[clearsky]['d'+varkey+'dt']
+        # obs = c4gldata[key].frames['stats']['records_all_stations_end_obs_stats'].loc[clearsky]['d'+varkey+'dt']
     
-        mod = c4gldata[key].frames['stats']['records_all_stations_mod_stats']['d'+varkey+'dt']
-        obs = c4gldata[key].frames['stats']['records_all_stations_obs_afternoon_stats']['d'+varkey+'dt']
+        mod = c4gldata[key].frames['stats']['records_all_stations_end_mod_stats']['d'+varkey+'dt']
+        obs = c4gldata[key].frames['stats']['records_all_stations_end_obs_stats']['d'+varkey+'dt']
         print ('filtering classes that have sufficient samples: ', include_koeppen)
-        filter_classess = (c4gldata[key].frames['stats']['records_all_stations_ini'].KGCname.isin(include_koeppen))
+        filter_classes = (c4gldata[key].frames['stats']['records_all_stations_ini'].KGCname.isin(include_koeppen))
         mod = mod.loc[filter_classes]
         obs = obs.loc[filter_classes]
+
     
         nbins=40       
         x, y = obs.values,mod.values
@@ -665,7 +669,7 @@ if args.make_figures:
     # ax = fig.add_axes([0.05,0.00,0.15,0.15]) #[*left*, *bottom*, *width*,    *height*]
     # leg = []
     # for ikey,key in enumerate(args.experiments.strip().split(' ')):
-    #     leg1, = ax.plot([],colors[ikey]+'o' ,markersize=10)
+    #     leg1, = ax.plot([],colors[ikey]+markers[ikey] ,markersize=10)
     #     leg.append(leg1)
     # ax.axis('off')
     # #leg1 =
@@ -702,7 +706,7 @@ if args.make_figures:
     fig.show()  
 
     koeppenlookuptable = koeppenlookuptable.sort_index()
-    if bool(args.show_control_parameters):
+    if args.show_control_parameters == 'True':
 
 
         pkmn_type_colors = [
@@ -748,7 +752,7 @@ if args.make_figures:
         key = list(args.experiments.strip().split(' '))[ikey]
         data_all = pd.DataFrame()
 
-        tempdatamodstats = pd.DataFrame(c4gldata[key].frames['stats']['records_all_stations_obs_afternoon_stats'].copy())
+        tempdatamodstats = pd.DataFrame(c4gldata[key].frames['stats']['records_all_stations_end_obs_stats'].copy())
         
 
         tempdatamodstats["source"] = "soundings"
@@ -780,7 +784,7 @@ if args.make_figures:
         for ikey,key in enumerate(list(args.experiments.strip().split(' '))):
             keylabel = keylabels[ikey]
 
-            tempdatamodstats = pd.DataFrame(c4gldata[key].frames['stats']['records_all_stations_mod_stats'].copy())
+            tempdatamodstats = pd.DataFrame(c4gldata[key].frames['stats']['records_all_stations_end_mod_stats'].copy())
             tempdataini_this= pd.DataFrame(c4gldata[key].frames['stats']['records_all_stations_ini'].copy())
 
             tempdatamodstats['dates']= tempdataini_this.ldatetime.dt.date
@@ -797,9 +801,7 @@ if args.make_figures:
             tempdataini = tempdataini.set_index(['source_index','STNID','dates'])
     
 
-            #print('hello2')
             index_intersect = tempdataini.index.intersection(tempdatamodstats.index)
-            #print('hello3')
 
             tempdataini = tempdataini.loc[index_intersect]
             #print('hello4')
@@ -905,6 +907,7 @@ if args.make_figures:
                                  #gridspec_kw=dict(height_ratios=(1, 3), 
                                  gridspec_kw=dict(hspace=0.20,wspace=0.08,top=0.94,bottom=0.06,left=0.15,right=0.99))
 
+        varkey = 'q'
         data_all['d'+varkey+'dt ['+units[varkey]+'/h]'] *= 1000.  
 
         icol = 0
