@@ -146,11 +146,15 @@ if bool(args.make_figures):
         #axes_taylor[varkey] = fig.add_subplot(2,3,i+3)                                       
     
         #print(obs.std())
-        obs = c4gldata[args.experiments.strip().split()[0]].frames['stats']['records_all_stations_obs_afternoon_stats']['d'+varkey+'dt']
-        STD_OBS = obs.std()
         dias[varkey] =  TaylorDiagram(1., srange=[0.0,1.7],fig=fig, rect=(230+i+3),label='Reference')
+        dias[varkey].add_grid(zorder=-100.)
         dias[varkey]._ax.axis["left"].label.set_text(\
             "Normalized standard deviation")
+        i += 1
+    i = 1                                                                           
+    for varkey in ['h','theta','q']:                                                    
+        obs = c4gldata[args.experiments.strip().split()[0]].frames['stats']['records_all_stations_end_obs_stats']['d'+varkey+'dt']
+        STD_OBS = obs.std()
         if i == 1:
             axes[varkey].annotate('Normalized standard deviation',\
                         xy= (0.05,0.36),
@@ -172,19 +176,14 @@ if bool(args.make_figures):
         # Q95 = obs.quantile(0.95)
         # Q95 = obs.quantile(0.90)
         # Add RMS contours, and label them
-        contours = dias[varkey].add_contours(levels=5, colors='0.5') # 5 levels
-        dias[varkey].ax.clabel(contours, inline=1, fontsize=10, fmt='%.1f')
+        contours = dias[varkey].add_contours(levels=5, colors='0.7') # 5 levels
+        dias[varkey].ax.clabel(contours, inline=1, fontsize=10,fmt='%.1f')
         #dia._ax.set_title(season.capitalize())
+        i += 1
     
-        dias[varkey].add_grid()
-    
-    
-        #dia.ax.plot(x99,y99,color='k')
-    
-        
         for ikey,key in enumerate(args.experiments.strip(' ').split(' ')):
-            mod = c4gldata[key].frames['stats']['records_all_stations_mod_stats']['d'+varkey+'dt']
-            obs = c4gldata[key].frames['stats']['records_all_stations_obs_afternoon_stats']['d'+varkey+'dt']
+            mod = c4gldata[key].frames['stats']['records_all_stations_end_mod_stats']['d'+varkey+'dt']
+            obs = c4gldata[key].frames['stats']['records_all_stations_end_obs_stats']['d'+varkey+'dt']
             x, y = obs.values,mod.values
             print(key,len(obs.values))
     
@@ -193,7 +192,16 @@ if bool(args.make_figures):
             RMSE = rmse(obs,mod)                                               
             BIAS = np.mean(mod) - np.mean(obs)
             STD = mod.std()
-            
+
+            # print(STD)
+            # print(PR)
+            print(varkey,STD,STD_OBS,STD/STD_OBS,PR)
+            dias[varkey].add_sample(STD/STD_OBS, PR,
+                           marker='o', ms=7, ls='',
+                           #mfc='k', mec='k', # B&W
+                           mfc=colors[ikey], mec=colors[ikey], # Colors
+                           label=key,zorder=101)
+                
             fit = np.polyfit(x,y,deg=1)
 
             if varkey == 'q':
@@ -226,6 +234,7 @@ if bool(args.make_figures):
                                'Bias = '+format((BIAS*1000.),'0.2f')+r'$\,  \mathrm{g\,  kg^{-1}\,  h^{-1}}$'+' \n'+\
                                r'$R$ = '+format(PR,'0.2f')
                 ann = axes[varkey].annotate(annotate_text, xy=(0.95, .05 ), xycoords='axes fraction',fontsize=9,
+                # ann = axes[varkey].annotate(annotate_text, xy=(0.05, .97 ), xycoords='axes fraction',fontsize=9,
        horizontalalignment='right', verticalalignment='bottom' ,
         bbox={'edgecolor':'black',
                           'fc':'white',  
@@ -237,8 +246,8 @@ if bool(args.make_figures):
                                 'RMSE = '+format(RMSE,'0.1f')+r'$\,  \mathrm{m\, h^{-1}}$'+'\n'+\
                                 'Bias = '+format(BIAS,'0.1f')+r'$\,  \mathrm{m\, h^{-1}}$'+'\n'+\
                                 r'$R$ = '+format(PR,'0.2f')
-                ann = axes[varkey].annotate(annotate_text, xy=(0.05, .97 ), xycoords='axes fraction',fontsize=9,
-       horizontalalignment='left', verticalalignment='top' ,
+                ann = axes[varkey].annotate(annotate_text, xy=(0.95, .05 ), xycoords='axes fraction',fontsize=9,
+       horizontalalignment='right', verticalalignment='bottom' ,
         bbox={'edgecolor':'black',
                           'fc':'white',  
                               'boxstyle':'square',
@@ -250,8 +259,8 @@ if bool(args.make_figures):
                                 'Bias = '+format(BIAS,'0.3f')+r'$\, \mathrm{K\, h^{-1}}$'+'\n'+\
                                 r'$R$ = '+format(PR,'0.2f')
 
-                ann = axes[varkey].annotate(annotate_text, xy=(0.05, .97 ), xycoords='axes fraction',fontsize=9,
-       horizontalalignment='left', verticalalignment='top' ,
+                ann = axes[varkey].annotate(annotate_text, xy=(0.95, .05 ), xycoords='axes fraction',fontsize=9,
+       horizontalalignment='right', verticalalignment='bottom' ,
         bbox={'edgecolor':'black',
                           'fc':'white',  
                               'boxstyle':'square',
@@ -262,13 +271,6 @@ if bool(args.make_figures):
 
 
             
-            # print(STD)
-            # print(PR)
-            dias[varkey].add_sample(STD/STD_OBS, PR,
-                           marker='o', ms=5, ls='',
-                           #mfc='k', mec='k', # B&W
-                           mfc=colors[ikey], mec=colors[ikey], # Colors
-                           label=key)
     
         # put ticker position, see
         # https://matplotlib.org/examples/ticks_and_spines/tick-locators.html 
@@ -284,10 +286,10 @@ if bool(args.make_figures):
             istation = 0
             for icurrent_station,current_station in c4gldata[key].frames['worldmap']['stations'].table.iterrows():
                 indices =  (c4gldata[key].frames['stats']['records_all_stations_index'].get_level_values('STNID') == current_station.name)
-                station_mod = c4gldata[key].frames['stats']['records_all_stations_mod_stats']['d'+varkey+'dt'].iloc[indices]
-                station_obs = c4gldata[key].frames['stats']['records_all_stations_obs_afternoon_stats']['d'+varkey+'dt'].iloc[indices]
+                station_end_mod = c4gldata[key].frames['stats']['records_all_stations_end_mod_stats']['d'+varkey+'dt'].iloc[indices]
+                station_obs = c4gldata[key].frames['stats']['records_all_stations_end_obs_stats']['d'+varkey+'dt'].iloc[indices]
     
-                axes[varkey].scatter(station_obs,station_mod,marker=symbols[istation],color=colors[ikey])
+                axes[varkey].scatter(station_obs,station_end_mod,marker=symbols[istation],color=colors[ikey])
                          #  label=key+", "+\
                          #                    'R = '+str(round(PR[0],3))+', '+\
                          #                    'RMSE = '+str(round(RMSE,5))+', '+\
@@ -300,12 +302,12 @@ if bool(args.make_figures):
             # #                              'RMSE = '+str(round(RMSE,5))+', '+\
             # #                              'BIAS = '+str(round(BIAS,5)),s=1.,color=colors[ikey])
                 
-                dias[varkey].add_sample(station_mod.std()/station_obs.std(),
-                               pearsonr(station_mod,station_obs)[0],#annotate=symbols[istation],
-                               marker=symbols[istation], ms=5, ls='',
+                dias[varkey].add_sample(station_end_mod.std()/station_obs.std(),
+                               pearsonr(station_end_mod,station_obs)[0],#annotate=symbols[istation],
+                               marker=symbols[istation], ms=7, ls='',
                                mfc='k', mec='k', # B&W
                                #mfc=colors[ikey], mec=colors[ikey], # Colors
-                               label=key)
+                               label=key,zorder=100)
 
                 istation += 1
     
@@ -332,11 +334,11 @@ if bool(args.make_figures):
         i +=1
           
         axes[varkey].set_aspect('equal')
-        low  = c4gldata[key].frames['stats']['records_all_stations_mod_stats']['d'+varkey+'dt'].min()
-        high  = c4gldata[key].frames['stats']['records_all_stations_mod_stats']['d'+varkey+'dt'].max()
+        low  = c4gldata[key].frames['stats']['records_all_stations_end_mod_stats']['d'+varkey+'dt'].min()
+        high  = c4gldata[key].frames['stats']['records_all_stations_end_mod_stats']['d'+varkey+'dt'].max()
 
-        low  = np.min([low,c4gldata[key].frames['stats']['records_all_stations_obs_afternoon_stats']['d'+varkey+'dt'].min()])
-        high  = np.max([high,c4gldata[key].frames['stats']['records_all_stations_obs_afternoon_stats']['d'+varkey+'dt'].max()])
+        low  = np.min([low,c4gldata[key].frames['stats']['records_all_stations_end_obs_stats']['d'+varkey+'dt'].min()])
+        high  = np.max([high,c4gldata[key].frames['stats']['records_all_stations_end_obs_stats']['d'+varkey+'dt'].max()])
 
         low = low - (high - low)*0.1
         high = high + (high - low)*0.1
@@ -366,12 +368,12 @@ if bool(args.make_figures):
     leg = []
     isymbol = 0
     for icurrent_station,current_station in c4gldata[key].frames['worldmap']['stations'].table.iterrows():
-        leg1, = ax.plot([],'k'+symbols[isymbol] ,markersize=10)
+        leg1, = ax.plot([],'k'+symbols[isymbol] ,markersize=14)
         leg.append(leg1)
         isymbol += 1
     
     # symbol for all stations
-    leg1, = ax.plot([],'ko',markersize=10)
+    leg1, = ax.plot([],'ko',markersize=14)
     leg.append(leg1)
     
     
