@@ -14,6 +14,7 @@ from class4gl import class4gl_input, data_global,class4gl,units
 from interface_functions import *
 #from data_soundings import wyoming
 import yaml
+from yaml import CLoader
 import glob
 import pandas as pd
 import json
@@ -59,6 +60,8 @@ class records_iterator(object):
         self.ix = (self.ix+jump) 
         if self.ix >= len(self.records.index):
             raise StopIteration
+        if self.ix < 0:
+            raise StopIteration
 
         return self.records.index[self.ix], self.records.iloc[self.ix]
     def __prev__(self):
@@ -75,31 +78,39 @@ def get_record_yaml(yaml_file,index_start,index_end,mode='model_output'):
     #print('going to next observation',filename)
     yaml_file.seek(index_start)
 
+    print('index_start',index_start)
+    print('index_end',index_end)
     buf =  yaml_file.read(index_end- index_start).replace('inf','9e19').replace('nan','9e19').replace('---','')
 
-    os.system('mkdir -p '+TEMPDIR)
-    filebuffer = open(TEMPDIR+'/'+shortfn+'.buffer.yaml.'+str(index_start),'w')
-    filebuffer.write(buf)
-    filebuffer.close()
-    # print("HHHEEELOOOO",filename+'.buffer.yaml'+str(index_start))
-    
-    if which('ruby') is None:
-        raise RuntimeError ('ruby is not found. Aborting...')
-    command = 'ruby -rjson -ryaml -e "'+"puts YAML.load_file('"+TEMPDIR+'/'+shortfn+".buffer.yaml."+str(index_start)+"').to_json"+'" > '+TEMPDIR+'/'+shortfn+'.buffer.json.'+str(index_start)+' '
+    # # Ruby way -> fast
+    # os.system('mkdir -p '+TEMPDIR)
+    # filebuffer = open(TEMPDIR+'/'+shortfn+'.buffer.yaml.'+str(index_start),'w')
+    # filebuffer.write(buf)
+    # filebuffer.close()
+    # # print("HHHEEELOOOO",filename+'.buffer.yaml'+str(index_start))
+    # 
+    # if which('ruby') is None:
+    #     raise RuntimeError ('ruby is not found. Aborting...')
+    # command = 'ruby -rjson -ryaml -e "'+"puts YAML.load_file('"+TEMPDIR+'/'+shortfn+".buffer.yaml."+str(index_start)+"').to_json"+'" > '+TEMPDIR+'/'+shortfn+'.buffer.json.'+str(index_start)+' '
 
-    #command = '/apps/gent/CO7/sandybridge/software/Ruby/2.4.2-foss-2017b/bin/ruby -rjson -ryaml -e "'+"puts YAML.load(ARGF.read()).to_json"+'"'
-    print(command)
-    os.system(command)
-    jsonstream = open(TEMPDIR+'/'+shortfn+'.buffer.json.'+str(index_start))
-    record_dict = json.load(jsonstream)
-    jsonstream.close()
-    os.system('rm '+TEMPDIR+'/'+shortfn+'.buffer.yaml.'+str(index_start))
+    # #command = '/apps/gent/CO7/sandybridge/software/Ruby/2.4.2-foss-2017b/bin/ruby -rjson -ryaml -e "'+"puts YAML.load(ARGF.read()).to_json"+'"'
+    # print(command)
+    # os.system(command)
+    # jsonstream = open(TEMPDIR+'/'+shortfn+'.buffer.json.'+str(index_start))
+    # record_dict = json.load(jsonstream)
+    # jsonstream.close()
+    # os.system('rm '+TEMPDIR+'/'+shortfn+'.buffer.yaml.'+str(index_start))
+
+    record_dict = yaml.load(buf,Loader=CLoader)
 
 
     if mode =='model_output':
         modelout = class4gl()
         modelout.load_yaml_dict(record_dict)
-        os.system('rm '+TEMPDIR+'/'+shortfn+'.buffer.json.'+str(index_start))
+
+        # # needed in case of Ruby
+        # os.system('rm '+TEMPDIR+'/'+shortfn+'.buffer.json.'+str(index_start))
+        print('hello')
 
         return modelout
     elif mode == 'model_input':
@@ -108,11 +119,12 @@ def get_record_yaml(yaml_file,index_start,index_end,mode='model_output'):
         # datetimes are incorrectly converted to strings. We need to convert them
         # again to datetimes
         for key,value in record_dict['pars'].items():
+            # # needed in case of ruby
             # we don't want the key with columns that have none values
-            if value is not None: 
-                if key in ['lSunrise','lSunset','datetime','ldatetime','ldatetime_daylight','datetime_daylight',]:#(type(value) == str):
-               # elif (type(value) == str):
-                    record_dict['pars'][key] = dt.datetime.strptime(value,"%Y-%m-%d %H:%M:%S %z")
+            # if value is not None: 
+            #     if key in ['lSunrise','lSunset','datetime','ldatetime','ldatetime_daylight','datetime_daylight',]:#(type(value) == str):
+            #    # elif (type(value) == str):
+            #         record_dict['pars'][key] = dt.datetime.strptime(value,"%Y-%m-%d %H:%M:%S %z")
 
             if (value == 0.9e19) or (value == '.9e19'):
                 record_dict['pars'][key] = np.nan
@@ -123,13 +135,17 @@ def get_record_yaml(yaml_file,index_start,index_end,mode='model_output'):
                 for datakey,datavalue in record_dict[key].items():
                     record_dict[key][datakey] = [ np.nan if (x =='.9e19') else x for x in record_dict[key][datakey]]
 
-        #os.system('rm '+filename+'.buffer.json.'+str(index_start))
 
         c4gli = class4gl_input()
         #print(c4gli.logger,'hello')
         c4gli.load_yaml_dict(record_dict)
-        os.system('rm '+TEMPDIR+'/'+shortfn+'.buffer.json.'+str(index_start))
+
+        # # needed in case of ruby
+        # os.system('rm '+TEMPDIR+'/'+shortfn+'.buffer.json.'+str(index_start))
         return c4gli
+    else:
+        print('Warning. Mode '+mode+' not recorgnized. Returning None')
+        return None
 
 
 
@@ -193,6 +209,7 @@ class stations(object):
         self.table = self.table.set_index('STNID')
 
     def get_stations(self,suffix):
+        print(suffix)
         stations_list_files = glob.glob(self.path+'/?????_*_'+suffix+'.yaml')
         if len(stations_list_files) == 0:
             stations_list_files = glob.glob(self.path+'/?????_'+suffix+'.yaml')
@@ -218,7 +235,7 @@ class stations(object):
         stations_list = []
         for stations_list_file in stations_list_files:
             thisfile = open(stations_list_file,'r')
-            yamlgen = yaml.load_all(thisfile)
+            yamlgen = yaml.load_all(thisfile,Loader=CLoader)
             try:
                 first_record  = yamlgen.__next__()
             except:
@@ -239,13 +256,19 @@ class stations_iterator(object):
     def __init__(self,stations):
         self.stations = stations
         self.ix = -1 
+        print('self.ix',self.ix)
+        print(stations.table)
     def __iter__(self):
         return self
     def __next__(self,jump=1):
-        self.ix = (self.ix+jump) 
-        if ((self.ix >= len(self.stations.table.index)) or (self.ix < 0 )):
+        print('next jump',jump)
+        print('self.ix',self.ix)
+        if ((self.ix+jump >= len(self.stations.table.index)) or (self.ix+jump < 0 )):
             raise StopIteration
+        self.ix = (self.ix+jump) 
+        print('self.ix',self.ix)
         self.ix = np.mod(self.ix,len(self.stations.table)) 
+        print('self.ix',self.ix)
         return self.stations.table.index[self.ix], self.stations.table.iloc[self.ix]
     def set_row(self,row):
         self.ix = row
@@ -467,25 +490,25 @@ def get_records(stations,path_yaml,getchunk='all',subset='morning',refetch_recor
                         print('pkl file does not exist. I generate "'+\
                               path_yaml+'/'+pklfilename+'" from "'+path_yaml+'/'+yamlfilename+'"...')
                         generate_pkl = True
+                    elif refetch_records:
+                        print('refetch_records flag is True. I regenerate "'+\
+                              path_yaml+'/'+pklfilename+'" from "'+path_yaml+'/'+yamlfilename+'"...')
+                        generate_pkl = True
                     elif not (os.path.getmtime(path_yaml+'/'+yamlfilename) <  \
                         os.path.getmtime(path_yaml+'/'+pklfilename)):
                         print('pkl file older than yaml file, so I regenerate "'+\
                               path_yaml+'/'+pklfilename+'" from "'+path_yaml+'/'+yamlfilename+'"...')
                         generate_pkl = True
-
-                    if refetch_records:
-                        print('refetch_records flag is True. I regenerate "'+\
-                              path_yaml+'/'+pklfilename+'" from "'+path_yaml+'/'+yamlfilename+'"...')
-                        generate_pkl = True
                     if not generate_pkl:
                         records_station_chunk = pd.read_pickle(path_yaml+'/'+pklfilename)
-                        records_station = pd.concat([records_station,records_station_chunk])
+                        records_station = pd.concat([records_station,records_station_chunk],sort=True)
                        # irecord = 0
                     else:
                         with open(path_yaml+'/'+yamlfilename) as yaml_file:
 
                             dictout = {}
 
+                            #initialization (go to file position just after "---")
                             next_record_found = False
                             end_of_file = False
                             while (not next_record_found) and (not end_of_file):
@@ -494,39 +517,54 @@ def get_records(stations,path_yaml,getchunk='all',subset='morning',refetch_recor
                                 end_of_file = (linebuffer == '')
                             next_tell = yaml_file.tell()
                             
+                            # loop over different yaml profile records
                             while not end_of_file:
 
                                 print(' next record:',next_tell)
                                 current_tell = next_tell
                                 next_record_found = False
                                 yaml_file.seek(current_tell)
-                                os.system('mkdir -p '+TEMPDIR)
-                                filebuffer = open(TEMPDIR+'/'+yamlfilename+'.buffer.yaml.'+str(current_tell),'w')
+
+                                # # needed for Ruby
+                                # os.system('mkdir -p '+TEMPDIR)
+                                # filebuffer = open(TEMPDIR+'/'+yamlfilename+'.buffer.yaml.'+str(current_tell),'w')
+
                                 linebuffer = ''
+                                stringbuffer = ''
                                 while ( (not next_record_found) and (not end_of_file)):
-                                    filebuffer.write(linebuffer.replace('inf','0').replace('nan','0'))
+                                    # # needed for Ruby
+                                    # filebuffer.write(linebuffer.replace('inf','0').replace('nan','0'))
+                                    stringbuffer += linebuffer 
                                     linebuffer = yaml_file.readline()
                                     next_record_found = (linebuffer == '---\n')
                                     end_of_file = (linebuffer == '')
-                                filebuffer.close()
+                                # # needed for Ruby
+                                # filebuffer.close()
                                 
                                 next_tell = yaml_file.tell()
                                 index_start = current_tell
                                 index_end = next_tell
 
-                                
-                                if which('ruby') is None:
-                                    raise RuntimeError ('ruby is not found. Aborting...')
-                                #if ((irecord >= start) and (np.mod(irecord - start,2) == 0.) :
-                                command = 'ruby -rjson -ryaml -e "'+"puts YAML.load_file('"+TEMPDIR+'/'+yamlfilename+".buffer.yaml."+str(current_tell)+"').to_json"+'" > '+TEMPDIR+'/'+yamlfilename+'.buffer.json.'+str(current_tell)+' ' 
-                                print(command)
-                                
-                                os.system(command)
-                                #jsonoutput = subprocess.check_output(command,shell=True) 
-                                #print(jsonoutput)
-                                #jsonstream = io.StringIO(jsonoutput)
-                                jsonstream = open(TEMPDIR+'/'+yamlfilename+'.buffer.json.'+str(current_tell))
-                                record = json.load(jsonstream)
+                                # start direct yaml way -> slow
+                                record = yaml.load(stringbuffer,Loader=CLoader)
+                                # end direct way
+
+                                # # # start json ruby way -> much faster 
+                                # if which('ruby') is None:
+                                #     raise RuntimeError ('ruby is not found. Aborting...')
+                                # #if ((irecord >= start) and (np.mod(irecord - start,2) == 0.) :
+                                # command = 'ruby -rjson -ryaml -e "'+"puts YAML.load_file('"+TEMPDIR+'/'+yamlfilename+".buffer.yaml."+str(current_tell)+"').to_json"+'" > '+TEMPDIR+'/'+yamlfilename+'.buffer.json.'+str(current_tell)+' ' 
+                                # print(command)
+                                # 
+                                # os.system(command)
+                                # #jsonoutput = subprocess.check_output(command,shell=True) 
+                                # #print(jsonoutput)
+                                # #jsonstream = io.StringIO(jsonoutput)
+                                # jsonstream = open(TEMPDIR+'/'+yamlfilename+'.buffer.json.'+str(current_tell))
+                                # record = json.load(jsonstream)
+                                # # end json ruby way
+
+
                                 dictouttemp = {}
                                 for key,value in record['pars'].items():
                                     # we don't want the key with columns that have none values
@@ -535,28 +573,34 @@ def get_records(stations,path_yaml,getchunk='all',subset='morning',refetch_recor
                                        if (type(value) in regular_numeric_types):
                                             dictouttemp[key] = value
                                        elif key in ['lSunrise','lSunset','datetime','ldatetime','datetime_daylight','datetime_daylight','ldatetime_daylight','ldatetime_daylight']:#(type(value) == str):
-                                           #print (key,value) # dictouttemp[key] = dt.datetime.strptime(value[:-6],"%Y-%m-%d %H:%M:%S")
-                                           dictouttemp[key] = dt.datetime.strptime(value,"%Y-%m-%d %H:%M:%S %z")
-                                           # Workaround. Unfortunately, Ruby puts it in local time of the computer. Turn it back to UTC (note that UTC means actually local time)!!!
-                                           dictouttemp[key] = dictouttemp[key].astimezone(pytz.UTC)
+                                           dictouttemp[key] = value
+                                           # # needed for Ruby
+                                           # dictouttemp[key] = dt.datetime.strptime(value,"%Y-%m-%d %H:%M:%S %z")
+
+                                           # # Workaround. Unfortunately, Ruby puts it in local time of the computer. Turn it back to UTC (note that UTC means actually local time)!!!
+                                           # dictouttemp[key] = dictouttemp[key].astimezone(pytz.UTC)
                                 recordindex = record['index']
                                 dictouttemp['chunk'] = chunk
                                 dictouttemp['index_start'] = index_start
                                 dictouttemp['index_end'] = index_end
-                                os.system('rm '+TEMPDIR+'/'+yamlfilename+'.buffer.json.'+str(current_tell))
+                                # os.system('rm '+TEMPDIR+'/'+yamlfilename+'.buffer.json.'+str(current_tell))
                                 for key,value in dictouttemp.items():
                                     if key not in dictout.keys():
                                         dictout[key] = {}
                                     dictout[key][(STNID,chunk,recordindex)] = dictouttemp[key]
                                 print(' obs record registered')
-                                jsonstream.close()
-                                os.system('rm '+TEMPDIR+'/'+yamlfilename+'.buffer.yaml.'+str(current_tell))
+                                # # needed for Ruby
+                                # jsonstream.close()
+                                #  os.system('rm '+TEMPDIR+'/'+yamlfilename+'.buffer.yaml.'+str(current_tell))
                             records_station_chunk = pd.DataFrame.from_dict(dictout)
-                            records_station_chunk.index.set_names(('STNID','chunk','index'),inplace=True)
-                            print('writing table file ('+path_yaml+'/'+pklfilename+') for station '\
-                                  +str(STNID)+', chunk number '+str(chunk))
-                            records_station_chunk.to_pickle(path_yaml+'/'+pklfilename)
-                            records_station = pd.concat([records_station,records_station_chunk])
+                            if len(records_station_chunk) > 0:
+                                records_station_chunk.index.set_names(('STNID','chunk','index'),inplace=True)
+                                print('writing table file ('+path_yaml+'/'+pklfilename+') for station '\
+                                      +str(STNID)+', chunk number '+str(chunk))
+                                records_station_chunk.to_pickle(path_yaml+'/'+pklfilename)
+                                records_station = pd.concat([records_station,records_station_chunk])
+                            else:
+                                print('Warning. No records found in ',yaml_file)
                         # else:
                         #     os.system('rm '+pklfilename)
                 if (getchunk == 'all') and (pklfilename_unified not in pklchunks):
@@ -565,7 +609,7 @@ def get_records(stations,path_yaml,getchunk='all',subset='morning',refetch_recor
                                   +str(STNID))
                     records_station.to_pickle(path_yaml+'/'+pklfilename_unified)
 
-            records = pd.concat([records,records_station])
+            records = pd.concat([records,records_station],sort=True)
     return records
 
 def stdrel(mod,obs,columns):
