@@ -8,6 +8,7 @@ import datetime as dt
 import sys
 import pytz
 import math
+import logging
 
 
 arguments = []
@@ -27,7 +28,7 @@ arguments.append(dict(arg='--error_handling',\
                     default='dump_on_success',\
                     help="type of error handling: either\n - 'dump_on_success' (default)\n - 'dump_always'"))
 arguments.append(dict(arg='--diag_tropo',\
-                    default=['advt','advq','advu','advv'],\
+                    default='',#\'advt,advq,advu,advv',\
                     help="field to diagnose the mean in the troposphere (<= 3000m)"))
 arguments.append(dict(arg='--subset_forcing',
                     default='ini', 
@@ -48,7 +49,15 @@ arguments.append(dict(arg='--c4gl_path_lib',help="the path of the CLASS4GL progr
 arguments.append(dict(arg='--global_chunk_number',help="this is the batch number of the expected series of experiments according to split_by"))
 arguments.append(dict(arg='--station_chunk_number',help="this is the batch number according to split_by in case of considering one station"))
 arguments.append(dict(arg='--experiments_names', help="Alternative output names that are given to the experiments. By default, these are the same as --experiments") )
-
+arguments.append(dict(arg='--debug_level', type=str,default=None,help="Debug level according to the standard python logging module. ") )
+# {'CRITICAL': 50,
+#   'FATAL': 50,
+#   'ERROR': 40,
+#   'WARN': 30,
+#   'WARNING': 30,
+#   'INFO': 20,
+#   'DEBUG': 10,
+#   'NOTSET': 0}
 
 
 if __name__ == '__main__':
@@ -77,17 +86,17 @@ else:
 def execute(**kwargs):
     # note that with args, we actually mean the same as those specified with
     # the argparse module above
-
+    
     # overwrite the args according to the kwargs when the procedure is called
     # as module function
     for key,value in kwargs.items():
         args.__dict__[key]  = value
-
+    
     print("-- begin arguments --")
     for key,value in args.__dict__.items():
          print(key,': ',value)
     print("-- end arguments ----")
-
+    
     # load specified class4gl library
     if args.c4gl_path_lib is not None:
         sys.path.insert(0, args.c4gl_path_lib)
@@ -108,8 +117,15 @@ def execute(**kwargs):
     #  'v', 'v2m', 'vw', 'wq', 'wtheta', 'wthetae', 'wthetav', 'wthetae', 'zlcl']
     
     
+    # for iEXP in range(4):
+    #     EXPKEY = 'LCZ'+str(iEXP)
+    #     EXP_DEFS[EXPKEY] = {'sw_ac' : [],'sw_ap': True,'sw_lit': False, 'urban':'LCZ'+str(iEXP)}
+
+
     EXP_DEFS  =\
     {
+      'LCZ':{'sw_ac' : [],'sw_ap': True,'sw_lit': False, 'urban':'lcw1'},
+
       'BASE':{'sw_ac' : ['adv',],'sw_ap': True,'sw_lit': False},
     
       'NOADV':{'sw_ac' : [],'sw_ap': True,'sw_lit': False},
@@ -227,6 +243,9 @@ def execute(**kwargs):
                                   subset=args.subset_forcing,
                                   refetch_records=False,
                                   )
+    if len(records_morning) == 0:
+        raise IOError("No initialization records records found in "+\
+                      args.path_forcing+' (subset: '+args_subset_forcing+')')
     
     # note that if runtime is an integer number, we don't need to get the afternoon
     # profiles. 
@@ -237,6 +256,9 @@ def execute(**kwargs):
                                         subset='end',
                                         refetch_records=False,
                                         )
+        if len(records_afternoon) == 0:
+            raise IOError("No final state records found in "+\
+                          args.path_forcing+' (subset: '+args_subset_forcing+')')
         
         # print(records_morning.index)
         # print(records_afternoon.index)
@@ -313,11 +335,11 @@ def execute(**kwargs):
                                                         record_morning.index_start, 
                                                         record_morning.index_end,
                                                         mode='model_input')
-                        if args.diag_tropo is not None:
+                        if args.diag_tropo is not '':
                             print('add tropospheric parameters on advection and subsidence (for diagnosis)')
                             seltropo = (c4gli_morning.air_ac.p > c4gli_morning.air_ac.p.iloc[-1]+ 3000.*(- 1.2 * 9.81 ))
                             profile_tropo = c4gli_morning.air_ac[seltropo]
-                            for var in args.diag_tropo:#['t','q','u','v',]:
+                            for var in args.diag_tropo.split(','):#['t','q','u','v',]:
                                 if var[:3] == 'adv':
                                     mean_adv_tropo = np.mean(profile_tropo[var+'_x']+profile_tropo[var+'_y'] )
                                     c4gli_morning.update(source='era-interim',pars={var+'_tropo':mean_adv_tropo})
@@ -328,8 +350,8 @@ def execute(**kwargs):
                         if args.runtime == 'from_profile_pair':
                             record_afternoon = records_afternoon.loc[(STNID,chunk,index)]
                             c4gli_afternoon = get_record_yaml(file_afternoon, 
-                                                              record_afternoon.index_start, 
-                                                              record_afternoon.index_end,
+                                                              int(record_afternoon.index_start),
+                                                              int(record_afternoon.index_end),
                                                             mode='model_input')
                             runtime = int((c4gli_afternoon.pars.datetime_daylight - 
                                                  c4gli_morning.pars.datetime_daylight).total_seconds())
@@ -343,7 +365,7 @@ def execute(**kwargs):
                                             runtime})
                         c4gli_morning.update(source=expname, pars=exp)
     
-                        c4gl = class4gl(c4gli_morning)
+                        c4gl = class4gl(c4gli_morning,debug_level=args.debug_level)
     
                         if args.error_handling == 'dump_always':
                             try:
@@ -444,7 +466,7 @@ def execute(**kwargs):
         #                                         record_afternoon.index_start, 
         #                                         record_afternoon.index_end,
         #                                         mode='ini')
-    
+
 
 if __name__ == '__main__':
     #execute(**vars(args))
